@@ -30,7 +30,7 @@ static INLINE void prepare_coeffs(const InterpFilterParams *const filter_params,
     coeffs[3] = _mm_shuffle_epi32(coeff, 0xff);
 }
 
-static INLINE __m128i convolve(const __m128i *const s, const __m128i *const coeffs) {
+static INLINE __m128i svt_aom_convolve(const __m128i *const s, const __m128i *const coeffs) {
     const __m128i res_0 = _mm_madd_epi16(s[0], coeffs[0]);
     const __m128i res_1 = _mm_madd_epi16(s[1], coeffs[1]);
     const __m128i res_2 = _mm_madd_epi16(s[2], coeffs[2]);
@@ -47,7 +47,7 @@ static INLINE __m128i convolve_lo_x(const __m128i *const s, const __m128i *const
     ss[1] = _mm_unpacklo_epi8(s[1], _mm_setzero_si128());
     ss[2] = _mm_unpacklo_epi8(s[2], _mm_setzero_si128());
     ss[3] = _mm_unpacklo_epi8(s[3], _mm_setzero_si128());
-    return convolve(ss, coeffs);
+    return svt_aom_convolve(ss, coeffs);
 }
 
 static INLINE __m128i convolve_lo_y(const __m128i *const s, const __m128i *const coeffs) {
@@ -56,7 +56,7 @@ static INLINE __m128i convolve_lo_y(const __m128i *const s, const __m128i *const
     ss[1] = _mm_unpacklo_epi8(s[2], _mm_setzero_si128());
     ss[2] = _mm_unpacklo_epi8(s[4], _mm_setzero_si128());
     ss[3] = _mm_unpacklo_epi8(s[6], _mm_setzero_si128());
-    return convolve(ss, coeffs);
+    return svt_aom_convolve(ss, coeffs);
 }
 
 static INLINE __m128i convolve_hi_y(const __m128i *const s, const __m128i *const coeffs) {
@@ -65,7 +65,7 @@ static INLINE __m128i convolve_hi_y(const __m128i *const s, const __m128i *const
     ss[1] = _mm_unpackhi_epi8(s[2], _mm_setzero_si128());
     ss[2] = _mm_unpackhi_epi8(s[4], _mm_setzero_si128());
     ss[3] = _mm_unpackhi_epi8(s[6], _mm_setzero_si128());
-    return convolve(ss, coeffs);
+    return svt_aom_convolve(ss, coeffs);
 }
 
 static INLINE __m128i comp_avg(const __m128i *const data_ref_0, const __m128i *const res_unsigned,
