@@ -49,10 +49,10 @@
 **************************************/
 #ifdef _WIN32
 uint8_t        num_groups = 0;
-GROUP_AFFINITY group_affinity;
+GROUP_AFFINITY svt_aom_group_affinity;
 Bool           alternate_groups = 0;
 #elif defined(__linux__)
-cpu_set_t group_affinity;
+cpu_set_t svt_aom_group_affinity;
 #endif
 
 EbMemoryMapEntry *svt_dec_memory_map;
@@ -62,18 +62,18 @@ uint64_t         *svt_dec_total_lib_memory;
 uint32_t svt_dec_lib_malloc_count = 0;
 
 /* Track address for memory during change in resoultion*/
-EbMemoryMapEntry *memory_map_start_address;
-EbMemoryMapEntry *memory_map_end_address;
+EbMemoryMapEntry *svt_aom_memory_map_start_address;
+EbMemoryMapEntry *svt_aom_memory_map_end_address;
 
-void        asm_set_convolve_asm_table(void);
-void        init_intra_dc_predictors_c_internal(void);
-void        asm_set_convolve_hbd_asm_table(void);
-void        init_intra_predictors_internal(void);
+void        svt_aom_asm_set_convolve_asm_table(void);
+void        svt_aom_init_intra_dc_predictors_c_internal(void);
+void        svt_aom_asm_set_convolve_hbd_asm_table(void);
+void        svt_aom_init_intra_predictors_internal(void);
 extern void svt_av1_init_wedge_masks(void);
 void        dec_sync_all_threads(EbDecHandle *dec_handle_ptr);
 
-EbErrorType decode_multiple_obu(EbDecHandle *dec_handle_ptr, uint8_t **data, size_t data_size,
-                                uint32_t is_annexb);
+EbErrorType svt_aom_decode_multiple_obu(EbDecHandle *dec_handle_ptr, uint8_t **data,
+                                        size_t data_size, uint32_t is_annexb);
 
 static void dec_switch_to_real_time() {
 #if !defined(_WIN32)
@@ -109,8 +109,8 @@ static EbErrorType svt_dec_handle_ctor(EbDecHandle    **decHandleDblPtr,
     svt_dec_lib_malloc_count = 0;
 
     dec_handle_ptr->start_thread_process = FALSE;
-    memory_map_start_address             = NULL;
-    memory_map_end_address               = NULL;
+    svt_aom_memory_map_start_address     = NULL;
+    svt_aom_memory_map_end_address       = NULL;
 
     return return_error;
 }
@@ -232,15 +232,15 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
     int32_t use_high_bit_depth = recon_picture_buf->bit_depth == EB_EIGHT_BIT ? 0 : 1;
 
     luma = out_img->luma +
-        ((out_img->origin_y * out_img->y_stride + out_img->origin_x) << use_high_bit_depth);
+        ((out_img->org_y * out_img->y_stride + out_img->org_x) << use_high_bit_depth);
     if (recon_picture_buf->color_format != EB_YUV400) {
         cb = out_img->cb +
-            ((out_img->cb_stride * gcc_right_shift(out_img->origin_y, sy) +
-              gcc_right_shift(out_img->origin_x, sx))
+            ((out_img->cb_stride * gcc_right_shift(out_img->org_y, sy) +
+              gcc_right_shift(out_img->org_x, sx))
              << use_high_bit_depth);
         cr = out_img->cr +
-            ((out_img->cr_stride * gcc_right_shift(out_img->origin_y, sy) +
-              gcc_right_shift(out_img->origin_x, sx))
+            ((out_img->cr_stride * gcc_right_shift(out_img->org_y, sy) +
+              gcc_right_shift(out_img->org_x, sx))
              << use_high_bit_depth);
     }
 
@@ -255,8 +255,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
                 ASSERT(luma != NULL);
                 /* Luma */
                 dst     = luma;
-                pu2_src = (uint16_t *)recon_picture_buf->buffer_y + recon_picture_buf->origin_x +
-                    (recon_picture_buf->origin_y * recon_picture_buf->stride_y);
+                pu2_src = (uint16_t *)recon_picture_buf->buffer_y + recon_picture_buf->org_x +
+                    (recon_picture_buf->org_y * recon_picture_buf->stride_y);
 
                 for (uint32_t i = 0; i < ht; i++) {
                     for (j = 0; j < wd; j++) dst[j] = (uint8_t)pu2_src[j];
@@ -269,8 +269,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
                     /* Cb */
                     dst     = cb;
                     pu2_src = (uint16_t *)recon_picture_buf->buffer_cb +
-                        (recon_picture_buf->origin_x >> sx) +
-                        ((recon_picture_buf->origin_y >> sy) * recon_picture_buf->stride_cb);
+                        (recon_picture_buf->org_x >> sx) +
+                        ((recon_picture_buf->org_y >> sy) * recon_picture_buf->stride_cb);
 
                     for (uint32_t i = 0; i < ((ht + sy) >> sy); i++) {
                         for (j = 0; j < ((wd + sx) >> sx); j++) dst[j] = (uint8_t)pu2_src[j];
@@ -281,8 +281,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
                     /* Cr */
                     dst     = cr;
                     pu2_src = (uint16_t *)recon_picture_buf->buffer_cr +
-                        (recon_picture_buf->origin_x >> sx) +
-                        ((recon_picture_buf->origin_y >> sy) * recon_picture_buf->stride_cr);
+                        (recon_picture_buf->org_x >> sx) +
+                        ((recon_picture_buf->org_y >> sy) * recon_picture_buf->stride_cr);
 
                     for (uint32_t i = 0; i < ((ht + sy) >> sy); i++) {
                         for (j = 0; j < ((wd + sx) >> sx); j++) dst[j] = (uint8_t)pu2_src[j];
@@ -293,8 +293,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
             } else {
                 uint8_t *src, *dst;
                 dst = luma;
-                src = recon_picture_buf->buffer_y + recon_picture_buf->origin_x +
-                    (recon_picture_buf->origin_y * recon_picture_buf->stride_y);
+                src = recon_picture_buf->buffer_y + recon_picture_buf->org_x +
+                    (recon_picture_buf->org_y * recon_picture_buf->stride_y);
 
                 for (uint32_t i = 0; i < ht; i++) {
                     svt_memcpy(dst, src, wd);
@@ -305,8 +305,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
                 if (recon_picture_buf->color_format != EB_YUV400) {
                     /* Cb */
                     dst = cb;
-                    src = recon_picture_buf->buffer_cb + (recon_picture_buf->origin_x >> sx) +
-                        ((recon_picture_buf->origin_y >> sy) * recon_picture_buf->stride_cb);
+                    src = recon_picture_buf->buffer_cb + (recon_picture_buf->org_x >> sx) +
+                        ((recon_picture_buf->org_y >> sy) * recon_picture_buf->stride_cb);
 
                     for (uint32_t i = 0; i < ((ht + sy) >> sy); i++) {
                         svt_memcpy(dst, src, ((wd + sx) >> sx));
@@ -316,8 +316,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
 
                     /* Cr */
                     dst = cr;
-                    src = recon_picture_buf->buffer_cr + (recon_picture_buf->origin_x >> sx) +
-                        ((recon_picture_buf->origin_y >> sy) * recon_picture_buf->stride_cr);
+                    src = recon_picture_buf->buffer_cr + (recon_picture_buf->org_x >> sx) +
+                        ((recon_picture_buf->org_y >> sy) * recon_picture_buf->stride_cr);
 
                     for (uint32_t i = 0; i < ((ht + sy) >> sy); i++) {
                         svt_memcpy(dst, src, ((wd + sx) >> sx));
@@ -332,8 +332,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
 
             /* Luma */
             pu2_dst = (uint16_t *)luma;
-            pu2_src = (uint16_t *)recon_picture_buf->buffer_y + recon_picture_buf->origin_x +
-                (recon_picture_buf->origin_y * recon_picture_buf->stride_y);
+            pu2_src = (uint16_t *)recon_picture_buf->buffer_y + recon_picture_buf->org_x +
+                (recon_picture_buf->org_y * recon_picture_buf->stride_y);
 
             for (uint32_t i = 0; i < ht; i++) {
                 svt_memcpy(pu2_dst, pu2_src, sizeof(uint16_t) * wd);
@@ -345,8 +345,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
                 /* Cb */
                 pu2_dst = (uint16_t *)cb;
                 pu2_src = (uint16_t *)recon_picture_buf->buffer_cb +
-                    (recon_picture_buf->origin_x >> sx) +
-                    ((recon_picture_buf->origin_y >> sy) * recon_picture_buf->stride_cb);
+                    (recon_picture_buf->org_x >> sx) +
+                    ((recon_picture_buf->org_y >> sy) * recon_picture_buf->stride_cb);
 
                 for (uint32_t i = 0; i < ((ht + sy) >> sy); i++) {
                     svt_memcpy(pu2_dst, pu2_src, sizeof(uint16_t) * ((wd + sx) >> sx));
@@ -357,8 +357,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
                 /* Cr */
                 pu2_dst = (uint16_t *)cr;
                 pu2_src = (uint16_t *)recon_picture_buf->buffer_cr +
-                    (recon_picture_buf->origin_x >> sx) +
-                    ((recon_picture_buf->origin_y >> sy) * recon_picture_buf->stride_cr);
+                    (recon_picture_buf->org_x >> sx) +
+                    ((recon_picture_buf->org_y >> sy) * recon_picture_buf->stride_cr);
 
                 for (uint32_t i = 0; i < ((ht + sy) >> sy); i++) {
                     svt_memcpy(pu2_dst, pu2_src, sizeof(uint16_t) * ((wd + sx) >> sx));
@@ -523,7 +523,7 @@ EB_API EbErrorType svt_av1_dec_init(EbComponentType *svt_dec_component) {
 
     EbDecHandle *dec_handle_ptr = (EbDecHandle *)svt_dec_component->p_component_private;
 #ifdef ARCH_X86_64
-    EbCpuFlags cpu_flags = get_cpu_flags_to_use();
+    EbCpuFlags cpu_flags = svt_aom_get_cpu_flags_to_use();
 #else
     EbCpuFlags cpu_flags = 0;
 #endif
@@ -540,22 +540,22 @@ EB_API EbErrorType svt_av1_dec_init(EbComponentType *svt_dec_component) {
     dec_handle_ptr->showable_frame      = 0;
     dec_handle_ptr->seq_header.sb_size  = 0;
 
-    setup_common_rtcd_internal(cpu_flags);
+    svt_aom_setup_common_rtcd_internal(cpu_flags);
 
-    asm_set_convolve_asm_table();
+    svt_aom_asm_set_convolve_asm_table();
 
-    init_intra_dc_predictors_c_internal();
+    svt_aom_init_intra_dc_predictors_c_internal();
 
-    asm_set_convolve_hbd_asm_table();
+    svt_aom_asm_set_convolve_hbd_asm_table();
 
-    init_intra_predictors_internal();
+    svt_aom_init_intra_predictors_internal();
 
     svt_av1_init_wedge_masks();
 
     /************************************
     * Decoder Memory Init
     ************************************/
-    return_error = dec_mem_init(dec_handle_ptr);
+    return_error = svt_aom_dec_mem_init(dec_handle_ptr);
     if (return_error != EB_ErrorNone)
         return return_error;
 
@@ -580,14 +580,15 @@ EB_API EbErrorType svt_av1_dec_frame(EbComponentType *svt_dec_component, const u
 
         uint64_t frame_size = 0;
         frame_size          = data_end - data_start;
-        return_error = decode_multiple_obu(dec_handle_ptr, &data_start, frame_size, is_annexb);
+        return_error        = svt_aom_decode_multiple_obu(
+            dec_handle_ptr, &data_start, frame_size, is_annexb);
 
         if (return_error != EB_ErrorNone)
             assert(0);
 
-        dec_pic_mgr_update_ref_pic(dec_handle_ptr,
-                                   (EB_ErrorNone == return_error) ? 1 : 0,
-                                   dec_handle_ptr->frame_header.refresh_frame_flags);
+        svt_aom_dec_pic_mgr_update_ref_pic(dec_handle_ptr,
+                                           (EB_ErrorNone == return_error) ? 1 : 0,
+                                           dec_handle_ptr->frame_header.refresh_frame_flags);
 
         // Allow extra zero bytes after the frame end
         while (data < data_end) {
