@@ -18,11 +18,11 @@
 int16_t svt_aom_dc_quant_qtx(int32_t qindex, int32_t delta, EbBitDepth bit_depth);
 int16_t svt_aom_ac_quant_qtx(int32_t qindex, int32_t delta, EbBitDepth bit_depth);
 
-void    setup_segmentation_dequant(DecModCtxt *dec_mod_ctxt);
-void    av1_inverse_qm_init(DecModCtxt *dec_mod_ctxt, SeqHeader *seq_header);
-void    update_dequant(DecModCtxt *dec_mod_ctxt, SBInfo *sb_info);
-int32_t inverse_quantize(DecModCtxt *dec_mod_ctxt, PartitionInfo *part, BlockModeInfo *mode,
-                         int32_t *level, int32_t *qcoeffs, TxType tx_type, TxSize tx_size,
-                         int plane);
+void    svt_aom_setup_segmentation_dequant(DecModCtxt *dec_mod_ctxt);
+void    svt_aom_inverse_qm_init(DecModCtxt *dec_mod_ctxt, SeqHeader *seq_header);
+void    svt_aom_update_dequant(DecModCtxt *dec_mod_ctxt, SBInfo *sb_info);
+int32_t svt_aom_inverse_quantize(DecModCtxt *dec_mod_ctxt, PartitionInfo *part, BlockModeInfo *mode,
+                                 int32_t *level, int32_t *qcoeffs, TxType tx_type, TxSize tx_size,
+                                 int plane);
 
 #endif // EbDecInverseQuantize_h
