@@ -18,14 +18,15 @@
 extern "C" {
 #endif
 
-static INLINE int error_measure(int err) { return error_measure_lut[255 + err]; }
+static INLINE int error_measure(int err) { return svt_aom_error_measure_lut[255 + err]; }
 
 // Returns the error between the result of applying motion 'wm' to the frame
 // described by 'ref' and the frame described by 'dst'.
 int64_t svt_av1_warp_error(EbWarpedMotionParams *wm, int use_hbd, int bd, const uint8_t *ref,
                            const uint8_t *ref_2b, int width, int height, int stride, uint8_t *dst,
                            int p_col, int p_row, int p_width, int p_height, int p_stride,
-                           int subsampling_x, int subsampling_y, int64_t best_error);
+                           int subsampling_x, int subsampling_y, uint8_t chess_refn,
+                           int64_t best_error);
 
 // Returns the error between the frame described by 'ref' and the frame
 // described by 'dst'.
